@@ -1,6 +1,6 @@
 package CatalystX::Resource::Controller::Resource;
 {
-    $CatalystX::Resource::Controller::Resource::VERSION = '0.002004';
+  $CatalystX::Resource::Controller::Resource::VERSION = '0.004001';
 }
 use Moose;
 use namespace::autoclean;
@@ -14,125 +14,124 @@ use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
 
 with qw/
     CatalystX::Component::Traits
-    /;
+/;
 
 # merge traits from app config with local traits
-has '+_trait_merge' => ( default => 1 );
+has '+_trait_merge' => (default => 1);
 
 __PACKAGE__->config(
-    traits => [
-        qw/
-            List
-            Show
-            Delete
-            Form
-            Create
-            Edit
-            /
-    ],
+    traits => [qw/
+        List
+        Show
+        Delete
+        Form
+        Create
+        Edit
+    /],
     action_roles => ['MatchRequestMethod'],
 );
 
+
 has 'model' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
-has 'identifier_columns' => (
+
+has 'identifier_candidates' => (
     is      => 'ro',
     isa     => 'ArrayRef',
-    default => sub { [qw/ name title /] },
+    default => sub {[ qw/ name title / ]},
 );
 
+
 has 'resultset_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'resources_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'resource_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
     required => 1,
 );
 
+
 has 'parent_key' => (
     is        => 'ro',
     isa       => NonEmptySimpleStr,
     predicate => 'has_parent',
 );
 
+
 has 'parents_accessor' => (
     is  => 'ro',
     isa => NonEmptySimpleStr,
 );
 
+
 has 'redirect_mode' => (
     is      => 'rw',
     isa     => NonEmptySimpleStr,
     default => 'list',
 );
 
+
 has 'error_path' => (
     is      => 'ro',
     isa     => NonEmptySimpleStr,
     default => '/default',
 );
 
+
 sub _redirect {
     my ( $self, $c ) = @_;
 
     my $path;
-    my $mode     = $self->redirect_mode;
+    my $mode = $self->redirect_mode;
     my @captures = @{ $c->request->captures };
-    my $action   = $c->action->name;
+    my $action = $c->action->name;
 
     ########################
     # redirect_mode 'list' #
     ########################
-# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
-# path: /parents/1/resources/3/move_next => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/create      => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
     if ( $mode eq 'list' ) {
         pop(@captures)
             unless $action eq 'create';
-        $path = $c->uri_for_action( $self->action_for('list'), \@captures );
+        $path = $c->uri_for_action($self->action_for('list'), \@captures);
     }
 
     ########################
     # redirect_mode 'show' #
     ########################
-# path: /parents/1/resources/create      => redirect_path: /parents/1/resources/<id>/show
-# path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/3/show
-# path: /parents/1/resources/3/move_next => redirect_path: /parents/1/resources/3/show
-# path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
+    # path: /parents/1/resources/create      => redirect_path: /parents/1/resources/<id>/show
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/1/resources/3/show
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/resources/list
     elsif ( $mode eq 'show' ) {
         if ( $action eq 'create' ) {
-            my $id_of_created_resource
-                = $c->stash->{ $self->resource_key }->id;
+            my $id_of_created_resource = $c->stash->{ $self->resource_key }->id;
             push @captures, $id_of_created_resource;
-            $path
-                = $c->uri_for_action( $self->action_for('show'), \@captures );
-        }
-        elsif ($action eq 'edit'
-            || $action eq 'move_next'
-            || $action eq 'move_previous' )
-        {
-            $path
-                = $c->uri_for_action( $self->action_for('show'), \@captures );
+            $path = $c->uri_for_action($self->action_for('show'), \@captures);
         }
         elsif ( $action eq 'delete' ) {
             pop(@captures);
-            $path
-                = $c->uri_for_action( $self->action_for('list'), \@captures );
+            $path = $c->uri_for_action($self->action_for('list'), \@captures);
+        }
+        elsif ( $action eq 'edit' ) {
+            $path = $c->uri_for_action($self->action_for('show'), \@captures);
         }
     }
 
@@ -145,23 +144,17 @@ sub _redirect {
     # path: /resources/3/edit                => redirect_path: /resources/list
     # path: /parents/1/resources/3/delete    => redirect_path: /parents/1/show
     # path: /resources/3/delete              => redirect_path: /resources/list
-    # path: /parents/1/resources/3/move_next => redirect_path: /parents/1/show
-    # path: /resources/3/move_next           => redirect_path: /resources/list
     elsif ( $mode eq 'show_parent' ) {
         if ( $self->has_parent ) {
-            my @chain
-                = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
+            my @chain = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
 
             # base_with_id action of parent
             my $parent_base_with_id_action;
-            if ( $action eq 'create' ) {
+            if ($action eq 'create') {
                 $parent_base_with_id_action = $chain[-3];
-            }
-            elsif ($action eq 'edit'
-                || $action eq 'delete'
-                || $action eq 'move_next'
-                || $action eq 'move_previous' )
-            {
+            } elsif ($action eq 'edit'
+                    || $action eq 'delete'
+                ) {
                 $parent_base_with_id_action = $chain[-4];
                 pop @captures;
             }
@@ -171,17 +164,50 @@ sub _redirect {
 
             # private path of show action of parent
             my $parent_show_action_private_path = "$parent_namespace/show";
-            $path = $c->uri_for_action( $parent_show_action_private_path,
-                \@captures );
+            $path = $c->uri_for_action($parent_show_action_private_path, \@captures);
         }
         else {
-            $path = $c->uri_for_action( $self->action_for('list') );
+            $path = $c->uri_for_action($self->action_for('list'));
+        }
+    }
+
+    ####################################
+    # redirect_mode 'show_parent_list' #
+    ####################################
+    # path: /parents/1/resources/create      => redirect_path: /parents/list
+    # path: /parents/1/resources/3/edit      => redirect_path: /parents/list
+    # path: /parents/1/resources/3/delete    => redirect_path: /parents/list
+    elsif ( $mode eq 'show_parent_list' ) {
+        if ( $self->has_parent ) {
+            my @chain = @{ $c->dispatcher->expand_action( $c->action )->{chain} };
+
+            # base action of parent
+            my $parent_base_action;
+            if ($action eq 'create') {
+                $parent_base_action = $chain[-4];
+                pop @captures;
+            } elsif ($action eq 'edit' || $action eq 'delete') {
+                $parent_base_action = $chain[-5];
+                pop @captures;
+                pop @captures;
+            }
+
+            # parent namespace
+            my $parent_namespace = $parent_base_action->{namespace};
+
+            # private path of list action of parent
+            my $parent_list_action_private_path = "$parent_namespace/list";
+            $path = $c->uri_for_action($parent_list_action_private_path, \@captures);
+        }
+        else {
+            $path = $c->uri_for_action($self->action_for('list'));
         }
     }
 
     $c->res->redirect($path);
 }
 
+
 sub _msg {
     my ( $self, $c, $action, $id ) = @_;
 
@@ -215,24 +241,35 @@ sub _msg {
             ? $c->loc( 'resources.moved_previous', $self->_identifier($c) )
             : $self->_identifier($c) . " moved previous.";
     }
+    elsif ( $action eq 'move_to' ) {
+        return $c->can('loc')
+            ? $c->loc( 'resources.moved_to', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved.";
+    }
 }
 
+
 sub _identifier {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
 
-    for my $col ( @{ $self->identifier_columns } ) {
-        if (   $resource->result_source->has_column($col)
-            && defined $resource->$col
-            && $resource->$col )
-        {
-            return $resource->$col;
+    for my $identifier (@{ $self->identifier_candidates }) {
+        if (
+            $resource->can( $identifier )
+            && defined $resource->$identifier
+        ) {
+            return $resource->$identifier
         }
     }
 
-    return ucfirst( $self->resource_key );
+    my $identifier =
+        $resource->can('id')
+        ? $self->resource_key . ' (id: ' . $resource->id . ')'
+        : $self->resource_key;
+    return ucfirst( $identifier );
 }
 
+
 sub base : Chained('') PathPart('') CaptureArgs(0) {
     my ( $self, $c ) = @_;
 
@@ -249,6 +286,7 @@ sub base : Chained('') PathPart('') CaptureArgs(0) {
     $c->stash( $self->resultset_key => $resultset );
 }
 
+
 sub base_with_id : Chained('base') PathPart('') CaptureArgs(1) {
     my ( $self, $c, $id ) = @_;
     my $resource = $c->stash->{ $self->resultset_key }->find($id);
@@ -273,7 +311,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.002004
+version 0.004001
 
 =head1 ATTRIBUTES
 
@@ -281,18 +319,19 @@ version 0.002004
 
 required, the DBIC model associated with this resource. (e.g.: 'DB::CDs')
 
-=head2 identifier_columns
+=head2 identifier_candidates
 
 ArrayRef of column names used as name in messages.
 
 if you edit, delete, ... a resource a msg is stored in the stash.
-the first defined value of the provided columns will be used.
+the first candidate available as accessor on the resoure (tested with
+$row->can(...)) that returns a defined value will be used.
 
-example: "Resource 'Michael Jackson' has been deleted."
+example: "'Michael Jackson' has been deleted.", "'Artist (id: 3)' has been updated."
 
 default: [ 'name', 'title' ]
 
-if no identifier is found the resource_key is used
+if no identifier is found resource_key is used
 
 =head2 resultset_key
 
@@ -321,7 +360,7 @@ of this resource (accessor in DBIC has_many)
 (e.g.: 'tracks')
 this is required if parent_key is set
 
-=head2 redirect_mode list|show|show_parent
+=head2 redirect_mode list|show|show_parent|show_parent_list
 
 After a created/edit/delete action a redirect takes place.
 The redirect behavior can be controlled with the redirect_mode attribute.
@@ -336,7 +375,7 @@ documented in L<CatalystX::Resource>
 
 =head2 _redirect
 
-redirect request after create/edit/delete/move_next/move_previous
+redirect request after create/edit/delete
 
 =head2 _msg
 
