@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Create;
 {
-    $CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.002004';
+  $CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.004001';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -12,7 +12,8 @@ requires qw/
     resultset_key
     resource_key
     form
-    /;
+/;
+
 
 has 'activate_fields_create' => (
     is      => 'ro',
@@ -20,8 +21,8 @@ has 'activate_fields_create' => (
     default => sub { [] },
 );
 
-sub create : Method('GET') Method('POST') Chained('base') PathPart('create')
-    Args(0) {
+
+sub create : Method('GET') Method('POST') Chained('base') PathPart('create') Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resultset_key }->new_result( {} );
     $c->stash(
@@ -42,7 +43,7 @@ CatalystX::Resource::TraitFor::Controller::Resource::Create - a create action fo
 
 =head1 VERSION
 
-version 0.002004
+version 0.004001
 
 =head1 ATTRIBUTES
 
