@@ -1,6 +1,6 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Sortable;
 {
-    $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.002004';
+  $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.004001';
 }
 
 use MooseX::MethodAttributes::Role;
@@ -12,26 +12,35 @@ requires qw/
     _msg
     resource_key
     _redirect
-    /;
+/;
 
 # ABSTRACT: make your Resource sortable
 
-sub move_next : Method('POST') Chained('base_with_id') PathPart('move_next')
-    Args(0) {
+
+sub move_next : Method('POST') Chained('base_with_id') PathPart('move_next') Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_next;
     $c->flash( msg => $self->_msg( $c, 'move_next' ) );
-    $self->_redirect($c);
+    $c->res->redirect($c->req->referer // '/');
 }
 
-sub move_previous : Method('POST') Chained('base_with_id')
-    PathPart('move_previous') Args(0) {
+
+sub move_previous : Method('POST') Chained('base_with_id') PathPart('move_previous') Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_previous;
     $c->flash( msg => $self->_msg( $c, 'move_previous' ) );
-    $self->_redirect($c);
+    $c->res->redirect($c->req->referer // '/');
+}
+
+
+sub move_to : Method('POST') Chained('base_with_id') PathPart('move_to') Args(1) {
+    my ( $self, $c, $pos ) = @_;
+    my $resource = $c->stash->{ $self->resource_key };
+    $resource->move_to( $pos );
+    $c->flash( msg => $self->_msg( $c, 'move_to' ) );
+    $c->res->redirect($c->req->referer // '/');
 }
 
 1;
@@ -45,7 +54,7 @@ CatalystX::Resource::TraitFor::Controller::Resource::Sortable - makes your resou
 
 =head1 VERSION
 
-version 0.002004
+version 0.004001
 
 =head1 SYNOPSIS
 
@@ -97,6 +106,9 @@ Example: Artist has_many Albums has_many Songs
     # TestApp/Schema/Result/Resource/Song.pm
     __PACKAGE__->grouping_column('album_id');
 
+After a move operation you will always be redirected to the referer
+If no referer header is foudn you'll be redirected to '/'
+
 =head1 ACTIONS
 
 =head2 move_next
@@ -107,6 +119,10 @@ Example: Artist has_many Albums has_many Songs
 
     will switch the resource with the previous one
 
+=head2 move_to
+
+    move resource to denoted position
+
 =head1 AUTHOR
 
 David Schmidt <davewood@cpan.org>
